Class: DcGallery

Inherits:
Object
  • Object
show all
Includes:
Mongoid::Document, Mongoid::Timestamps
Defined in:
app/models/dc_gallery.rb

Overview

Schema information

Collection name: dc_gallery : Pictures gallery

_id BSON::ObjectId _id doc_id BSON::ObjectId Document id of the gallery title String Title name for picture description String Short description picture String Picture filename thumbnail String Picture thumbnail

active Mongoid::Boolean Picture is active created_by BSON::ObjectId created_by updated_by BSON::ObjectId updated_by created_at Time created_at updated_at Time updated_at

Picture gallery collection holds data about picture galleries for different types of documents.