Class: DcIdent

Inherits:
Object
  • Object
show all
Includes:
Mongoid::Document, Mongoid::Timestamps
Defined in:
app/models/dc_ident.rb

Overview

Schema information

Collection name: dc_ident : Additional identification

_id BSON::ObjectId _id created_at Time created_at updated_at Time updated_at key String Key which defines ident value String Ident value

dc_idents are similar to mongoid hash structure and can be used for saveing key/value object. Fact is that I have overlooked the existance of MongoDB Hash field type and this structure will be used until drg_forms_field which will use Hash field type is created.