Class: DcPolicyRule

Inherits:
Object
  • Object
show all
Includes:
DcPolicyRuleConcern
Defined in:
app/models/dc_policy_rule.rb

Overview

Schema information

Collection name: dc_policy_rule : Access policy rules

_id BSON::ObjectId _id created_at Time created_at updated_at Time updated_at dc_policy_role_id Object User role access defined by this rule permission Integer Access permission

DcPolicyRule documents define policies for accessing data. DRG CMS uses policy rules for defining policies in DcSite, DcPermission and DcFolderPermission documents.

Since they are defined as polymorphic they can be embedded into any application specific model by specifying this line in the model:

embeds_many :dc_policy_rules, as: :policy_rules