Class: DcAdStat
- Inherits:
-
Object
- Object
- DcAdStat
- Includes:
- Mongoid::Document, Mongoid::Timestamps
- Defined in:
- app/models/dc_ad_stat.rb
Overview
Schema information
Collection name: dc_ad_stat : Ads statistics
_id BSON::ObjectId _id created_at Time created_at updated_at Time updated_at dc_ad_id BSON::ObjectId dc_ad_id ip String ip type Integer type
Documents in this collection holds data about displays and clicks on ads which can be further processed for statistical purposes.